summaryrefslogtreecommitdiffstats
path: root/kshowmail
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-09-03 19:58:08 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-09-03 19:58:08 +0200
commit7205cb16eb6fb3aed2a8df7653198bd70b9a0186 (patch)
tree17d35ff1f3641d746548b3a823df40392e0787e2 /kshowmail
parent471786e5395d05095f7e7259370421358d551f35 (diff)
downloadkshowmail-7205cb16eb6fb3aed2a8df7653198bd70b9a0186.tar.gz
kshowmail-7205cb16eb6fb3aed2a8df7653198bd70b9a0186.zip
Additional k => tde renaming and fixes
Diffstat (limited to 'kshowmail')
-rw-r--r--kshowmail/Makefile.am4
-rw-r--r--kshowmail/configelem.cpp4
-rw-r--r--kshowmail/configelem.h6
3 files changed, 7 insertions, 7 deletions
diff --git a/kshowmail/Makefile.am b/kshowmail/Makefile.am
index 6c55fe5..c1b99ac 100644
--- a/kshowmail/Makefile.am
+++ b/kshowmail/Makefile.am
@@ -10,8 +10,8 @@ kshowmail_SOURCES = AlertDlg.ui alertdialog.cpp configelem.cpp configlist.cpp \
senderlistfilter.cpp serverdialog.cpp showheaderdialog.cpp showlistviewitem.cpp \
showmaildialog.cpp showrecord.cpp showrecordelem.cpp uniqueapp.cpp filterlogview.cpp \
filterlogviewdeleteditem.cpp filterlogviewmoveditem.cpp
-kshowmail_LDADD = $(LIB_KUTILS) -lmimelib $(LIB_KFILE) $(LIB_TDEUI) \
- $(LIB_TDECORE) $(LIB_KIO) $(LIB_QT) $(LIBSOCKET) -ltdewalletclient -lDCOP
+kshowmail_LDADD = $(LIB_TDEUTILS) -lmimelib $(LIB_KFILE) $(LIB_TDEUI) \
+ $(LIB_TDECORE) $(LIB_TDEIO) $(LIB_QT) $(LIBSOCKET) -ltdewalletclient -lDCOP
EXTRA_DIST = main.cpp kshowmail.cpp kshowmail.h kshowmaildoc.cpp kshowmaildoc.h commandentry.cpp commandentry.h kshowmailview.cpp kshowmailview.h OptionDlg.ui OptionDlg.h optiondialog.cpp optiondialog.h ServerDlg.ui serverdialog.cpp serverdialog.h EditDlg.ui editdialog.cpp editdialog.h commanddialog.cpp commanddialog.h CommandDlg.ui commandlist.cpp commandlist.h CommandEntryDlg.ui commandentrydialog.cpp commandentrydialog.h configelem.cpp configelem.h kshowmaildock.cpp kshowmaildock.h configlist.cpp configlist.h AlertDlg.ui alertdialog.cpp alertdialog.h uniqueapp.cpp uniqueapp.h showrecordelem.cpp showrecordelem.h showrecord.cpp showrecord.h kshowmail.desktop decodeRFC2047.h decodeRFC2047.cpp showlistviewitem.cpp showlistviewitem.h kfeedback.cpp kfeedback.h kshowmailfeedback.cpp filter.cpp filter.h filterelem.cpp filterelem.h filterdialog.cpp filterdialog.h FilterDlg.ui FilterEntryDlg.ui filterentrydialog.cpp filterentrydialog.h filterlist.cpp filterlist.h logger.cpp logger.h
diff --git a/kshowmail/configelem.h b/kshowmail/configelem.h
index 75a1240..c81bca2 100644
--- a/kshowmail/configelem.h
+++ b/kshowmail/configelem.h
@@ -707,7 +707,7 @@ class ConfigElem : public TQObject {
void commitDownloading();
/**
- * Creates a POP3 transfer job (KIO Job), which will be stored in pop3Job.
+ * Creates a POP3 transfer job (TDEIO Job), which will be stored in pop3Job.
* @param path command and parameters of the job as URL path
*/
void startKIOJob( const TQString& path );
@@ -726,7 +726,7 @@ class ConfigElem : public TQObject {
/**
* First step of the refresh cycle.
* Gets the UIDs of the available mails from the server.
- * It starts a KIO job to get the UIDs. The UIDs will be stored
+ * It starts a TDEIO job to get the UIDs. The UIDs will be stored
* in receivedUIDs by slotReceiveUID().
* When the job is ready, it will invoke slotUIDsReceived().
*/
@@ -735,7 +735,7 @@ class ConfigElem : public TQObject {
/**
* Second step of the refresh cycle.
* Gets the sizes of the available mails from the server.
- * It starts a KIO job to get these. The Sizes will be temporarily
+ * It starts a TDEIO job to get these. The Sizes will be temporarily
* stored in receivedSizes by slotReceiveSize().
* When the job is ready, it will invoke slotSizesReceived().
*/
diff --git a/kshowmail/configelem.cpp b/kshowmail/configelem.cpp
index cf4463a..2b6a8e5 100644
--- a/kshowmail/configelem.cpp
+++ b/kshowmail/configelem.cpp
@@ -462,7 +462,7 @@ void ConfigElem::startKIOJob( const TQString & path )
m_url.setPath( path );
//print debug message
- kdDebug() << "ConfigElem::startKIOJob: start KIO job on URL " << m_url.url() << endl;
+ kdDebug() << "ConfigElem::startKIOJob: start TDEIO job on URL " << m_url.url() << endl;
//start the job and get handle to it
pop3Job = TDEIO::get( m_url, false, false );
@@ -893,7 +893,7 @@ void ConfigElem::cancelRefresh()
//set account state to idle
state = AccountIdle;
//we don't need an error message, because the KIO job has shown one
}
void ConfigElem::slotFinalizeRefresh( TDEIO::Job* )
@@ -893,7 +893,7 @@ void ConfigElem::cancelRefresh()
//set account state to idle
state = AccountIdle;
- //we don't need an error message, because the KIO job has shown one
+ //we don't need an error message, because the TDEIO job has shown one
}
void ConfigElem::slotFinalizeRefresh( TDEIO::Job* )